@@ -1,6 +1,6 @@
 package Mozilla::DOM;
 
-# $Id: DOM.pm,v 1.12 2005/04/18 05:30:24 slanning Exp $
+# $Id: DOM.pm,v 1.13 2005/04/20 15:50:34 slanning Exp $
 
 use 5.008;
 use strict;
@@ -10,7 +10,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
@@ -18,6 +18,12 @@ __PACKAGE__->bootstrap($VERSION);
 
 # -----------------------------------------------------------------------------
 
+package Mozilla::DOM::Supports;
+
+# every interface inherits from this eventually
+
+# -----------------------------------------------------------------------------
+
 package Mozilla::DOM::AbstractView;
 
 our @ISA = qw(Mozilla::DOM::Supports);
@@ -256,6 +262,18 @@ our @ISA = qw(Mozilla::DOM::Supports);
 
 # -----------------------------------------------------------------------------
 
+package Mozilla::DOM::Window2;
+
+our @ISA = qw(Mozilla::DOM::Window);
+
+# -----------------------------------------------------------------------------
+
+package Mozilla::DOM::WindowInternal;
+
+our @ISA = qw(Mozilla::DOM::Window2);
+
+# -----------------------------------------------------------------------------
+
 package Mozilla::DOM::WindowCollection;
 
 our @ISA = qw(Mozilla::DOM::Supports);
@@ -407,6 +425,30 @@ use constant END_TO_START            => 3;
 
 # -----------------------------------------------------------------------------
 
+package Mozilla::DOM::History;
+
+our @ISA = qw(Mozilla::DOM::Supports);
+
+# -----------------------------------------------------------------------------
+
+package Mozilla::DOM::Location;
+
+our @ISA = qw(Mozilla::DOM::Supports);
+
+# -----------------------------------------------------------------------------
+
+package Mozilla::DOM::Navigator;
+
+our @ISA = qw(Mozilla::DOM::Supports);
+
+# -----------------------------------------------------------------------------
+
+package Mozilla::DOM::Screen;
+
+our @ISA = qw(Mozilla::DOM::Supports);
+
+# -----------------------------------------------------------------------------
+
 package Mozilla::DOM::WebBrowser;
 
 our @ISA = qw(Mozilla::DOM::Supports);
@@ -415,12 +457,6 @@ our @ISA = qw(Mozilla::DOM::Supports);
 
 # -----------------------------------------------------------------------------
 
-package Mozilla::DOM::Supports;
-
-# every interface inherits from this eventually
-
-# -----------------------------------------------------------------------------
-
 package Mozilla::DOM::HTMLAreaElement;
 
 our @ISA = qw(Mozilla::DOM::HTMLElement);
